# BSD 3-Clause License
#
# Copyright (c) 2021, LANDrop
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# 1. Redistributions of source code must retain the above copyright notice, this
#    list of conditions and the following disclaimer.
#
# 2. Redistributions in binary form must reproduce the above copyright notice,
#    this list of conditions and the following disclaimer in the documentation
#    and/or other materials provided with the distribution.
#
# 3. Neither the name of the copyright holder nor the names of its
#    contributors may be used to endorse or promote products derived from
#    this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
# FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
# SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
# CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
# OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


from PyQt5.QtCore import QSettings, QStandardPaths, QDir
from PyQt5.QtWidgets import QApplication
from PyQt5.QtNetwork import QHostInfo


class Settings:
    @staticmethod
    def deviceName() -> str:
        d = QHostInfo.localHostName()
        return QSettings().value("deviceName", d)

    @staticmethod
    def downloadPath() -> str:
        d = QStandardPaths.writableLocation(QStandardPaths.DownloadLocation)
        d += QDir.separator() + QApplication.applicationName()
        return QSettings().value("downloadPath", d)

    @staticmethod
    def discoverable() -> bool:
        value = QSettings().value("discoverable", True)
        assert value in ["true", "false"]
        return value == "true"

    @staticmethod
    def serverPort() -> int:
        return QSettings().value("serverPort", 0)

    @staticmethod
    def setDeviceName(deviceName: str) -> None:
        QSettings().setValue("deviceName", deviceName)

    @staticmethod
    def setDownloadPath(downloadPath: str) -> None:
        QSettings().setValue("downloadPath", downloadPath)

    @staticmethod
    def setDiscoverable(discoverable: bool) -> None:
        QSettings().setValue("discoverable", discoverable)

    @staticmethod
    def setServerPort(serverPort: int) -> None:
        QSettings().setValue("serverPort", serverPort)
